<?php

require_once( 'include/football_common.php' );
require_once( 'include/database_common.php' );
require_once( 'include/database_games.php' );
require_once( 'include/database_teams.php' );
require_once( 'include/database_rankings.php' );

function display_game_pick( $pick )
{
	$gameInfo = get_game_by_id( $pick['GameID'] );
	$scoreboardInfo = get_scoreboard_game_by_id( $pick['GameID'] );
	if( $gameInfo == [] )
	{
		echo 'Failed to find game info';
		return;
	}

	$pickInfo = get_pick_by_game_id( $pick['GameID'] );
	$underDog = 0;
	$gameType = get_pick_type_by_id( $pick['GameID'] );
	if( $gameType == "upset" )
		$underDog = get_pick_underdog( $pick['GameID'] );

	$neutral = $gameInfo['neutral_site'];
	$awayTeam = get_team_by_id( $gameInfo['away_id'] );
	$homeTeam = get_team_by_id( $gameInfo['home_id'] );
	$awayName = $awayTeam['school'];
	$homeName = $homeTeam['school'];
	$awayDisplayName = $awayTeam['school'] . " " . $awayTeam['mascot'];
	$homeDisplayName = $homeTeam['school'] . " " . $homeTeam['mascot'];
	$awayRecord = get_team_record( $awayName );
	if($awayRecord == null)
		$awayRecord = ['TotalWins' => '0','TotalLosses' => '0','TotalTies' => '0'];
	$homeRecord = get_team_record( $homeName );
	if($homeRecord == null)
		$homeRecord = ['TotalWins' => '0','TotalLosses' => '0','TotalTies' => '0'];
	$awayRank = get_team_rank_by_week( $awayName, $gameInfo['week'], $gameInfo['season_type'] );
	$homeRank = get_team_rank_by_week( $homeName, $gameInfo['week'], $gameInfo['season_type'] );
	$odds = "";

	$awayPickIcon = "";
	$homePickIcon = "";

	if( count( $pickInfo ) != 0 )
	{
		if( $pickInfo[0]['Winner'] == 0 )
		{
			if( $pick['Winner'] == $gameInfo['away_id'] )
				$awayPickIcon = "images/question.png";
			else if( $pick['Winner'] == $gameInfo['home_id'] )
				$homePickIcon = "images/question.png";
	
			if( $scoreboardInfo != [] )
			{
				if( $scoreboardInfo['status'] == "in_progress" )
					$gameTime = 'Quarter ' . $scoreboardInfo['period'] . ", " . $scoreboardInfo['clock'];
				else
					$gameTime = get_game_date_time_by_id( $scoreboardInfo['id'] );
			}
			else
				$gameTime = get_game_date_time_by_id( $gameInfo['id'] );

				
		}
		else
		{
			
			if( $pick['Winner'] == $pickInfo[0]['Winner'] )
			{
				if( $pick['Winner'] == $gameInfo['away_id'] )
					$awayPickIcon = "images/correct.png";
				else if( $pick['Winner'] == $gameInfo['home_id'] )
					$homePickIcon = "images/correct.png";
			}
			else
			{
				if( $pick['Winner'] == $gameInfo['away_id'] )
					$awayPickIcon = "images/wrong.png";
				else if( $pick['Winner'] == $gameInfo['home_id'] )
					$homePickIcon = "images/wrong.png";
			}
			if( $scoreboardInfo != [] )
			{
				if( $scoreboardInfo['status'] == "in_progress" )
					$gameTime = 'Quarter ' . $scoreboardInfo['period'] . ", " . $scoreboardInfo['clock'];
				else
					$gameTime = get_game_date_time_by_id( $scoreboardInfo['id'] );
			}
			else
				$gameTime = get_game_date_time_by_id( $gameInfo['id'] );
				
		}
	}

	echo '<div class="pickContainer">' . "\n";
	echo "\t" . '<div class="game_status">' . "\n";
	echo "\t\t" . '<div class="left_field"></div>' . "\n";
	echo "\t\t" . '<div class="right_field">' . "\n";
	echo "\t\t\t" . '<span>' . $gameTime . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	echo "\t" . '<div class="pick_team">' . "\n";
	echo "\t\t" . '<div class="game_team">' . "\n";
	echo "\t\t\t" . '<div class="team_icon">' . "\n";
	echo "\t\t\t\t" . '<a><img src="' . $awayTeam['logo'] . '" width="30px" /></a>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t\t" . '<div class="team_name">' . "\n";
	if( $awayRank != 0 )
		echo "\t\t\t\t" . '<span>#' . $awayRank . ' ' . $awayDisplayName . ' (' . $awayRecord['TotalWins'] . '-' . $awayRecord['TotalLosses'] . '-' . $awayRecord['TotalTies'] . ')' . '</span>' . "\n";
	else
		echo "\t\t\t\t" . '<span>' . $awayDisplayName . ' (' . $awayRecord['TotalWins'] . '-' . $awayRecord['TotalLosses'] . '-' . $awayRecord['TotalTies'] . ')' . '</span>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t\t" . '<div class="team_score">' . "\n";
	if( $scoreboardInfo != [] )
		echo "\t\t\t\t" . '<span>' . $scoreboardInfo['awayPoints'] . '</span>' . "\n";
	else
		echo "\t\t\t\t" . '<span>' . $gameInfo['away_points'] . '</span>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="user_pick">' . "\n";
	if( $awayPickIcon != "" )
		echo "\t\t\t" . '<a><img src="' . $awayPickIcon . '" width="30px" /></a>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	echo "\t" . '<div class="pick_team">' . "\n";
	echo "\t\t" . '<div class="game_team">' . "\n";
	echo "\t\t\t" . '<div class="team_icon">' . "\n";
	echo "\t\t\t\t" . '<span><a><img src="' . $homeTeam['logo'] . '" width="30px" /></a></span>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t\t" . '<div class="team_name">' . "\n";
	if( $homeRank != 0 )
		echo "\t\t\t\t" . '<span>#' . $homeRank . ' ' . $homeDisplayName . ' (' . $homeRecord['TotalWins'] . '-' . $homeRecord['TotalLosses'] . '-' . $homeRecord['TotalTies'] . ')' . '</span>' . "\n";
	else
		echo "\t\t\t\t" . '<span>' . $homeDisplayName . ' (' . $homeRecord['TotalWins'] . '-' . $homeRecord['TotalLosses'] . '-' . $homeRecord['TotalTies'] . ')' . '</span>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t\t" . '<div class="team_score">' . "\n";
	if( $scoreboardInfo != [] )
		echo "\t\t\t\t" . '<span>' . $scoreboardInfo['homePoints'] . '</span>' . "\n";
	else
		echo "\t\t\t\t" . '<span>' . $gameInfo['home_points'] . '</span>' . "\n";
	echo "\t\t\t" . '</div>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="user_pick">' . "\n";
	if( $homePickIcon != "" )
		echo "\t\t\t" . '<a><img src="' . $homePickIcon . '" width="30px" /></a>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	if( $neutral )
	{
		echo "\t" . '<div class="pick_extra">' . "\n";
	    echo "\t\t" . '<div class="left_field">Played at neutral location</div>' . "\n";
		if( !empty( $odds ) )
		{
			echo "\t\t" . '<div class="right_field">' . $odds . '</div>' . "\n";
			echo "\t" . '</div>' . "\n";
		}
		else
		{
			if( !empty( $odds ) )
			{
				echo "\t" . '<div class="pick_extra">' . "\n";
				echo "\t\t" . '<div class="left_field">' . " " . '</div>' . "\n";
				echo "\t\t" . '<div class="right_field">' . $odds . '</div>' . "\n";
				echo "\t" . '</div>' . "\n";
	        }
		}
	}
	echo '</div>' . "\n";
}

function display_game_score( $gameId )
{
	$gameInfo = get_game_by_id( $gameId );
	if( $gameInfo == null )
	{
		echo 'Failed to find game info';
		return;
	}

	$gameTime = get_game_date_time_by_id( $gameId );

	$neutral = $gameInfo['neutral_site'];
	$awayTeam = get_team_by_id( $gameInfo['away_id'] );
	$homeTeam = get_team_by_id( $gameInfo['home_id'] );
	$awayName = $awayTeam['school'];
	$homeName = $homeTeam['school'];
	$awayDisplayName = $awayTeam['school'] . " " . $awayTeam['mascot'];
	$homeDisplayName = $homeTeam['school'] . " " . $homeTeam['mascot'];
	$awayRecord = get_team_record( $awayName );
	$homeRecord = get_team_record( $homeName );
	$awayRank = get_team_rank_by_week( $awayName, $gameInfo['week'], $gameInfo['season_type'] );
	$homeRank = get_team_rank_by_week( $homeName, $gameInfo['week'], $gameInfo['season_type'] );
	$odds = "";

	echo '<div class="gameContainer">' . "\n";
	echo "\t" . '<div class="game_status">' . "\n";
	echo "\t\t" . '<div class="left_field"></div>' . "\n";
	echo "\t\t" . '<div class="right_field">' . "\n";
	echo "\t\t\t" . '<span>' . $gameTime . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	echo "\t" . '<div class="game_team">' . "\n";
	echo "\t\t" . '<div class="team_icon">' . "\n";
	echo "\t\t\t" . '<a><img src="' . $awayTeam['logo'] . '" width="30px" /></a>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="team_name">' . "\n";
	if( $awayRank != 0 )
		echo "\t\t\t" . '<span>#' . $awayRank . ' ' . $awayDisplayName . '</span>' . "\n";
	else
		echo "\t\t\t" . '<span>' . $awayDisplayName . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="team_score">' . "\n";
	echo "\t\t\t" . '<span>' . $gameInfo['away_points'] . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	echo "\t" . '<div class="game_team">' . "\n";
	echo "\t\t" . '<div class="team_icon">' . "\n";
	echo "\t\t\t" . '<span><a><img src="' . $homeTeam['logo'] . '" width="30px" /></a></span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="team_name">' . "\n";
	if( $homeRank != 0 )
		echo "\t\t\t" . '<span>#' . $homeRank . ' ' . $homeDisplayName . '</span>' . "\n";
	else
		echo "\t\t\t" . '<span>' . $homeDisplayName . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t\t" . '<div class="team_score">' . "\n";
	echo "\t\t\t" . '<span>' . $gameInfo['home_points'] . '</span>' . "\n";
	echo "\t\t" . '</div>' . "\n";
	echo "\t" . '</div>' . "\n";
	if( $neutral )
	{
		echo "\t" . '<div class="game_extra">' . "\n";
		echo "\t\t" . '<div class="left_field">Played at neutral location</div>' . "\n";
		if( !empty( $odds ) )
			echo "\t\t" . '<div class="right_field">' . $odds . '</div>' . "\n";
		echo "\t" . '</div>' . "\n";
	}
	else
	{
		if( !empty( $odds ) )
		{
			echo "\t" . '<div class="game_extra">' . "\n";
			echo "\t\t" . '<div class="left_field">' . " " . '</div>' . "\n";
			echo "\t\t" . '<div class="right_field">' . $odds . '</div>' . "\n";
			echo "\t" . '</div>' . "\n";
		}
	}
	echo '</div>' . "\n";
}

?>
