from CFDB_Classes import *
from CFDB_Fetcher import *
from CFDB_Database import CFDB_Database
from CFDB_UserDatabase import CFDB_UserDatabase
import sys
import json
import datetime
import wget

year = 2024

class NCAAFootball():
	def __init__(self):
		self.database = CFDB_Database()
		self.userDatabase = CFDB_UserDatabase()
		self.fetcher = CFDB_Fetcher()

	def InitializeDatabases(self):
		self.userDatabase.InitializeDatabase()

	def GetUserPointsByWeek( self, picks, userId, week, season ):
		correctPicks = self.userDatabase.GetUserCorrectPicksByWeek( userId, week, season )
		totalPoints = 0

		for correctPick in correctPicks:
			totalPoints += picks[correctPick[0]]

		return totalPoints

	def UpdatePicks(self):
		currentWeek = self.database.GetCurrentWeek()
		currentSeason = self.database.GetCurrentSeason()

		for week in range( 1, currentWeek+1 ):
			games = self.database.GetAllGameDataByWeek(week, 'regular')
			if games == None:
				return
			self.userDatabase.UpdatePicks( games, week, 'regular' )
		if currentSeason == 'postseason':
			games = self.database.GetAllGameDataByWeek(week, 'postseason')
			if games == None:
				return
			self.userDatabase.UpdatePicks( games, week, 'postseason' )

	def UpdateUserPoints(self):
		userIds = self.userDatabase.GetAllUserIds()
		currentWeek = self.database.GetCurrentWeek()
		currentSeason = self.database.GetCurrentSeason()
		totalWeeks = self.database.GetNumberOfWeeksInSeason()

		for user in userIds:
			totalPoints = 0
			for week in range( 1, currentWeek+1 ):
				pickInfo = self.userDatabase.GetPicksAndPointsByWeek( week, 'regular' )
				weeklyPoints = self.GetUserPointsByWeek( pickInfo, user, week, 'regular' )
				self.userDatabase.SetUserWeeklyPoints( user, week, 'regular', weeklyPoints )
				totalPoints = totalPoints + weeklyPoints
			if currentSeason == 'postseason':
				pickInfo = self.userDatabase.GetPicksAndPointsByWeek( 1, 'postseason' )
				weeklyPoints = self.GetUserPointsByWeek( pickInfo, user, 1, 'postseason' )
				self.userDatabase.SetUserWeeklyPoints( user, 1, currentSeason, weeklyPoints )
				totalPoints = totalPoints + weeklyPoints
			self.userDatabase.SetUserSeasonPoints( user, totalPoints )

if __name__ == "__main__":
	football = NCAAFootball()
	for arg in sys.argv:
		if arg == "-i" or arg == "i":
			football.InitializeDatabases()
		elif arg == "-u" or arg == "u":
			football.UpdatePicks()
			football.UpdateUserPoints()
			
