from CFDB_Fetcher import CFDB_Fetcher
from CFDB_Classes import *
from datetime import date
import json

class CFDB_Parser():
	def __init__(self):
		self.fetcher = CFDB_Fetcher()

	def ParseGame(self, gameData):
		return 0

	def ParseConference(self, conferenceData):
		return 0
	
	def ParseLocation(self, locationData):
		return 0

	def ParseRecord(self, recordData):
		return 0

	def ParseTeamRecord(self, teamRecordData):
		return 0

	def ParseTeam(self, teamData):
		return 0

	def ParseTeamSeason(self, teamSeasonData):
		teamSeason.school = teamSeasonData["school"]
		teamSeason.year = teamSeasonData["year"]
		teamSeason.games = teamSeasonData["games"]
		teamSeason.wins = teamSeasonData["wins"]
		teamSeason.losses = teamSeasonData["losses"]
		teamSeason.ties = teamSeasonData["ties"]
		teamSeason.preseason_rank = teamSeasonData["preseason_rank"]
		teamSeason.postseason_rank = teamSeasonData["postseason_rank"]
		teamSeason.srs = teamSeasonData["srs"]
		teamSeason.sp_overall = teamSeasonData["sp_overall"]
		teamSeason.sp_offense = teamSeasonData["sp_offense"]
		teamSeason.sp_defense = teamSeasonData["sp_defense"]

	def GetAllGames(self, year):
		rawData = self.fetcher.FetchGames(year)
		gamesData = json.loads(rawData)


	def GetCurrentSeason(self):
		rawData = self.fetcher.FetchSeasons()
		seasonData = json.loads(rawData)
		return seasonData['response'][0]

	def GetLeague(self, currentSeason):
		rawData = self.fetcher.FetchLeague(currentSeason)
		leagueData = json.loads(rawData)
		for league in leagueData['response']:
			if league['league']['name'] == "NCAA":
				return league['league']['id']
		return None

	def ParseGames(self, gamesData):
		games = []

		for gameData in gamesData['response']:
			game = NCAAFootballGame()
			game.gameID = gameData['game']['id']
			game.awayID = gameData['teams']['away']['id']
			if gameData['scores']['away']['quarter_1'] != "null":
				game.awayFirstScore = gameData['scores']['away']['quarter_1']
			else:
				game.awayFirstScore = 0
			if gameData['scores']['away']['quarter_2'] != "null":
				game.awaySecondScore = gameData['scores']['away']['quarter_2']
			else:
				game.awaySecondScore = 0
			if gameData['scores']['away']['quarter_3'] != "null":
				game.awayThirdScore = gameData['scores']['away']['quarter_3']
			else:
				game.awayThirdScore = 0
			if gameData['scores']['away']['quarter_4'] != "null":
				game.awayFourthScore = gameData['scores']['away']['quarter_4']
			else:
				game.awayFourthScore = 0
			if gameData['scores']['away']['overtime'] != "null":
				game.awayOTScore = gameData['scores']['away']['overtime']
			else:
				game.awayOTScore = 0
			if gameData['scores']['away']['total'] != "null":
				game.awayFinalScore = gameData['scores']['away']['total']
			else:
				game.awayFinalScore = 0
			game.homeID = gameData['teams']['home']['id']
			if gameData['scores']['home']['quarter_1'] != "null":
				game.homeFirstScore = gameData['scores']['home']['quarter_1']
			else:
				game.homeFirstScore = 0
			if gameData['scores']['home']['quarter_2'] != "null":
				game.homeSecondScore = gameData['scores']['home']['quarter_2']
			else:
				game.homeSecondScore = 0
			if gameData['scores']['home']['quarter_3'] != "null":
				game.homeThirdScore = gameData['scores']['home']['quarter_3']
			else:
				game.homeThirdScore = 0
			if gameData['scores']['home']['quarter_4'] != "null":
				game.homeFourthScore = gameData['scores']['home']['quarter_4']
			else:
				game.homeFourthScore = 0
			if gameData['scores']['home']['overtime'] != "null":
				game.homeOTScore = gameData['scores']['home']['overtime']
			else:
				game.homeOTScore = 0
			if gameData['scores']['home']['total'] != "null":
				game.homeFinalScore = gameData['scores']['home']['total']
			else:
				game.homeFinalScore = 0
			game.gameStatusShort = gameData['game']['status']['short']
			game.gameStatusLong = gameData['game']['status']['long']
			if gameData['game']['status']['timer'] != "null":
				game.gameTimer = gameData['game']['status']['timer']
			else:
				game.gameTimer = ""
			game.gameWeek = gameData['game']['week']
			game.gameDate = gameData['game']['date']['date']
			game.gameTime = gameData['game']['date']['time']
			if gameData['game']['venue']['name'] != "null":
				game.gameVenue = gameData['game']['venue']
				if gameData['game']['venue']['city'] != "null":
					game.gameVenue = game.gameVenue + gameData['game']['venue']['city']
			else:
				if gameData['game']['venue']['city'] != "null":
					game.gameVenue = gameData['game']['venue']['city']
			game.gameDivision = gameData['game']['stage']
			game.append(game)

		return games

	def GetAllGames(self, currentSeason, league):
		rawData = self.fetcher.FetchAllGames(league, currentSeason)
		gamesData = json.loads(rawData)
		return ParseGames(gamesData)

	def GetTodaysGames(self, currentSeason, league):
		today = date.today()
		rawData = self.fetcher.FetchGamesByDate(league, currentSeason, today)
		gamesData = json.loads(rawData)
		return ParseGames(gamesData)

	def GetTeam(self, teamID):
		team = NCAAFootballTeam()
		self.fetcher.FetchTeamByID(teamID)

	def GetStandings(self, season, league):
		teams = []

		rawData = self.fetcher.FetchStandings(league, season)
		teamsData = json.loads(rawData)
		for teamData in teamsData:
			team = NCAAFootballTeam()
			team.id = teamData['team']['id']
			team.name = teamData['team']['name']
			team.division = teamData['division']
			team.conference = teamData['conference']
			team.totalWins = teamData['team']['won']
			team.totalLosses = teamData['team']['lost']
			if teamData['team']['ties'] != "null":
				team.totalTies = teamData['team']['ties']
			else:
				team.totalTies = 0
			if teamData['records']['home'] != "null":
				team.homeRecord = teamData['records']['home']
			else:
				team.homeRecord = ""
			if teamData['records']['road'] != "null":
				team.roadRecord = teamData['records']['road']
			else:
				team.roadRecord = ""
			if teamData['records']['conference'] != "null":
				team.conferenceRecord = teamData['records']['conference']
			else:
				team.conferenceRecord = ""
			if teamData['records']['division'] != "null":
				team.divisionRecord = teamData['records']['division']
			else:
				team.divisionRecord = ""
			team.icon = teamData['team']['logo']

	def ParseScorePageForCurrentWeek(self):
		return None

	def ParseSeasons(self, league):
		return None

	def ParseFbsTeamsPage(self):
		return None

	def ParseLowerDivisionTeamsPage(self, division):
		return None

	def ParseTeamHomePage(self, teamName, teamURL):
		return None

	def ConvertStartDateToString( self, startDate ):
		return None

	def ConvertMonthDayToString( self, monthDay ):
		return None

	def ParseGameWeek( self, gamesData, division, gameList, teamList, week, season ):
		return 0

	def ParseFbsGameWeek( self, season, week, games, teams ):
		return None

	def ParseFcsGameWeek(self, season, week, games, teams):
		return None

	def ParseTeamRankings(self, week):
		return None

	def ParseGamesUpdate(self, week):
		return None
	
	def ParseTeamUpdate( self, teamId ):
		return None

	def ParseGameChronologies( self, week ):
		return None
